# -*- encoding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution	
#    Copyright (C) 2004-2009 Tiny SPRL (<http://tiny.be>). All Rights Reserved
#    $Id$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from mx import DateTime
import time
import math

from osv import fields, osv
from tools.translate import _


class hr_employee(osv.osv):
    
    _inherit = 'hr.employee'
    
    _columns = {
        'number' : fields.integer("Employee Number", size=8),
        'number_conf' : fields.integer("Conf. Number", size=8),
        'number_pers' : fields.integer("Pers. Number", size=8),    
        'surnames' : fields.char("Surnames", size=128),
        'start_date' : fields.date("Starting date"),
        'driv_date' : fields.date("Driving license first date"),
        'driv_cad_date' : fields.date("Driving license caducity date"),
        'tacografo' : fields.date("Tacograph"),
        'section': fields.char('Section', size=32),
        'ssnid': fields.char('SS Nº', size=32),
        'hire_date' : fields.date("Hiring date"),
        'contract': fields.char('Contract', size=32),
        'phone': fields.char('Phone', size=32),
        'phone2': fields.char('Second Phone', size=32),
        'email': fields.char('Personal Email', size=128),
        'acc_number': fields.char('Account Number', size=64),
       # 'bank_ids': fields.one2many('res.partner.bank', 'partner_id', 'Banks'),
        'acts': fields.text('Acts'),
        'languages': fields.selection([('euskera_si','Euskera Si'),('euskera_no','Euskera No')], 'Languages'),
        'size': fields.char('Clothes size', size=32),
        #'medical_ids': fields.one2many('checkup', 'hr_employee', 'Medical Checkups'),
        'experience': fields.text('Professional Experience'),
        'service_ids': fields.one2many('hr.service', 'emp_id','Equipment Services'),
        'session_ids': fields.one2many('hr.session', 'emp_id', 'Done Sessions'),
        'session_notes': fields.text('Session Notes'),
        'family_ids':fields.one2many('hr.family','employee_id','Family'),
    }

hr_employee()


class hr_family(osv.osv):
    _name = "hr.family"
    _description = "Family of the employee"
    _columns = {
        'name' : fields.char("Name", size=64, required=True),
        'surnames': fields.char("Surnames", size=128),
        'relation': fields.char("Relation", size=64),
        'vat': fields.char('VAT', size=32),
        'birthdate': fields.date("Birthday"),
        'gender': fields.selection([('male','Male'),('female','Female')], 'Gender'),
        'notes': fields.text('Notes'),
        'employee_id': fields.many2one('hr.employee', 'Parent'),   
    }
hr_family()

class hr_course(osv.osv):
    _name = "hr.course"
    _description = "Course"
    _columns = {
        'name' : fields.char("Name", size=64, required=True),
        'description' : fields.text('Description'),
        'active' : fields.boolean('Active'),
        'training_ids' : fields.one2many('hr.training','course_id','Trainings'),
        'notes': fields.text('Notes'),
        'duration' : fields.time("Duration", size=64),
    }
    _defaults= {
          'active': lambda *a: True,  
    }  
    
hr_course()

class hr_training(osv.osv):
    _name = "hr.training"
    _description = "Training and Controls of employees"
    _columns = {
        'name' : fields.char("Name", size=64, required=True),
        'emp_ids': fields.many2many('hr.employee', 'training_empl_rel','hr_training_id','hr_emploe_id','Employees'),
        'course_id': fields.many2one('hr.course', 'Course'),
        'date' : fields.date("Starting Date"),
        'duration' : fields.time("Duration", size=64),
        'enterprise': fields.many2one('res.partner', 'Training Partner'),
        'trainer' : fields.char("Trainer", size=64),
        'notes': fields.text('Notes'),       
    }
    
hr_training()

class hr_session(osv.osv):
    _name= "hr.session"
    _description = "Employe done sessions"
    _columns = {
#                'name' : fields.char("Name", size=64, required=True),
                'emp_id' : fields.many2one('hr.employee', 'Employee'),
                'training_id': fields.many2one('hr.training', 'Training/Control'),
                'date' : fields.date("Date"),
                'duration' : fields.time("Duration", size=64),
                'enterprise': fields.many2one('res.partner', 'Partner in Charge'),
                'level' : fields.char("Level", size=64),
                }
hr_session()

class hr_service(osv.osv):
    _name = "hr.service"
    _description = "Services of equipment by employees"
    _columns = {
        'reference' : fields.char("Reference", size=64, required=True),
        'emp_id' : fields.many2one('hr.employee', 'Employee', required=True),#, 
        #'equip_id': fields.one2many('hr.equipment', 'service_ids'), #, required=True
        'equip_id':fields.one2many('hr.equipment','service_ids','Material'),
        'date' : fields.date("Delivery Date"),
        'notes': fields.text('Notes'),
         }
    
hr_service()

class hr_equipment(osv.osv):
    _name = "hr.equipment"
    _description = "Equipment to be used by employees"
    _columns = {
        'product_id':fields.many2one('product.product', 'Product', required=True),
        'product_uom_qty':fields.float('Quantity', digits=(16, 2)),
        'product_uom':fields.many2one('product.uom', 'Unit of Measure', required=True),
        #'service_ids' : fields.many2one('hr.service','hr.service'),
        'service_ids':fields.many2one('hr.service', 'Service'),
        'notes': fields.text('Notes'),
    }
hr_equipment()

class hr_employee(osv.osv):
    
    _inherit = 'hr.employee'
    
    _columns = {
                'training_ids': fields.many2many('hr.training', 'training_empl_rel','hr_emploe_id','hr_training_id', 'Trainings & Controls'),
    }

hr_employee()